==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkSelectionSource.java <==
// java wrapper for vtkSelectionSource object
//

package vtk;
import vtk.*;

public class vtkSelectionSource extends vtkSelectionAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddID_2(int id0,int id1);
  public void AddID(int id0,int id1)
    { AddID_2(id0,id1); }

  private native void AddStringID_3(int id0,String id1);
  public void AddStringID(int id0,String id1)
    { AddStringID_3(id0,id1); }

  private native void AddLocation_4(double id0,double id1,double id2);
  public void AddLocation(double id0,double id1,double id2)
    { AddLocation_4(id0,id1,id2); }

  private native void AddThreshold_5(double id0,double id1);
  public void AddThreshold(double id0,double id1)
    { AddThreshold_5(id0,id1); }

  private native void AddBlock_6(int id0);
  public void AddBlock(int id0)
    { AddBlock_6(id0); }

  private native void RemoveAllIDs_7();
  public void RemoveAllIDs()
    { RemoveAllIDs_7(); }

  private native void RemoveAllStringIDs_8();
  public void RemoveAllStringIDs()
    { RemoveAllStringIDs_8(); }

  private native void RemoveAllThresholds_9();
  public void RemoveAllThresholds()
    { RemoveAllThresholds_9(); }

  private native void RemoveAllLocations_10();
  public void RemoveAllLocations()
    { RemoveAllLocations_10(); }

  private native void RemoveAllBlocks_11();
  public void RemoveAllBlocks()
    { RemoveAllBlocks_11(); }

  private native void SetContentType_12(int id0);
  public void SetContentType(int id0)
    { SetContentType_12(id0); }

  private native int GetContentType_13();
  public int GetContentType()
    { return GetContentType_13(); }

  private native void SetFieldType_14(int id0);
  public void SetFieldType(int id0)
    { SetFieldType_14(id0); }

  private native int GetFieldType_15();
  public int GetFieldType()
    { return GetFieldType_15(); }

  private native void SetContainingCells_16(int id0);
  public void SetContainingCells(int id0)
    { SetContainingCells_16(id0); }

  private native int GetContainingCells_17();
  public int GetContainingCells()
    { return GetContainingCells_17(); }

  private native void SetInverse_18(int id0);
  public void SetInverse(int id0)
    { SetInverse_18(id0); }

  private native int GetInverse_19();
  public int GetInverse()
    { return GetInverse_19(); }

  private native void SetArrayName_20(String id0);
  public void SetArrayName(String id0)
    { SetArrayName_20(id0); }

  private native String GetArrayName_21();
  public String GetArrayName()
    { return GetArrayName_21(); }

  private native void SetArrayComponent_22(int id0);
  public void SetArrayComponent(int id0)
    { SetArrayComponent_22(id0); }

  private native int GetArrayComponent_23();
  public int GetArrayComponent()
    { return GetArrayComponent_23(); }

  private native void SetCompositeIndex_24(int id0);
  public void SetCompositeIndex(int id0)
    { SetCompositeIndex_24(id0); }

  private native int GetCompositeIndex_25();
  public int GetCompositeIndex()
    { return GetCompositeIndex_25(); }

  private native void SetHierarchicalLevel_26(int id0);
  public void SetHierarchicalLevel(int id0)
    { SetHierarchicalLevel_26(id0); }

  private native int GetHierarchicalLevel_27();
  public int GetHierarchicalLevel()
    { return GetHierarchicalLevel_27(); }

  private native void SetHierarchicalIndex_28(int id0);
  public void SetHierarchicalIndex(int id0)
    { SetHierarchicalIndex_28(id0); }

  private native int GetHierarchicalIndex_29();
  public int GetHierarchicalIndex()
    { return GetHierarchicalIndex_29(); }

  private native void SetQueryString_30(String id0);
  public void SetQueryString(String id0)
    { SetQueryString_30(id0); }

  private native String GetQueryString_31();
  public String GetQueryString()
    { return GetQueryString_31(); }

  public vtkSelectionSource() { super(); }

  public vtkSelectionSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-aarch64.pkg.tar.xz: vtk/vtkSelectionSource.java <==
// java wrapper for vtkSelectionSource object
//

package vtk;
import vtk.*;

public class vtkSelectionSource extends vtkSelectionAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddID_2(int id0,int id1);
  public void AddID(int id0,int id1)
    { AddID_2(id0,id1); }

  private native void AddStringID_3(int id0,String id1);
  public void AddStringID(int id0,String id1)
    { AddStringID_3(id0,id1); }

  private native void AddLocation_4(double id0,double id1,double id2);
  public void AddLocation(double id0,double id1,double id2)
    { AddLocation_4(id0,id1,id2); }

  private native void AddThreshold_5(double id0,double id1);
  public void AddThreshold(double id0,double id1)
    { AddThreshold_5(id0,id1); }

  private native void AddBlock_6(int id0);
  public void AddBlock(int id0)
    { AddBlock_6(id0); }

  private native void RemoveAllIDs_7();
  public void RemoveAllIDs()
    { RemoveAllIDs_7(); }

  private native void RemoveAllStringIDs_8();
  public void RemoveAllStringIDs()
    { RemoveAllStringIDs_8(); }

  private native void RemoveAllThresholds_9();
  public void RemoveAllThresholds()
    { RemoveAllThresholds_9(); }

  private native void RemoveAllLocations_10();
  public void RemoveAllLocations()
    { RemoveAllLocations_10(); }

  private native void RemoveAllBlocks_11();
  public void RemoveAllBlocks()
    { RemoveAllBlocks_11(); }

  private native void SetContentType_12(int id0);
  public void SetContentType(int id0)
    { SetContentType_12(id0); }

  private native int GetContentType_13();
  public int GetContentType()
    { return GetContentType_13(); }

  private native void SetFieldType_14(int id0);
  public void SetFieldType(int id0)
    { SetFieldType_14(id0); }

  private native int GetFieldType_15();
  public int GetFieldType()
    { return GetFieldType_15(); }

  private native void SetContainingCells_16(int id0);
  public void SetContainingCells(int id0)
    { SetContainingCells_16(id0); }

  private native int GetContainingCells_17();
  public int GetContainingCells()
    { return GetContainingCells_17(); }

  private native void SetInverse_18(int id0);
  public void SetInverse(int id0)
    { SetInverse_18(id0); }

  private native int GetInverse_19();
  public int GetInverse()
    { return GetInverse_19(); }

  private native void SetArrayName_20(String id0);
  public void SetArrayName(String id0)
    { SetArrayName_20(id0); }

  private native String GetArrayName_21();
  public String GetArrayName()
    { return GetArrayName_21(); }

  private native void SetArrayComponent_22(int id0);
  public void SetArrayComponent(int id0)
    { SetArrayComponent_22(id0); }

  private native int GetArrayComponent_23();
  public int GetArrayComponent()
    { return GetArrayComponent_23(); }

  private native void SetCompositeIndex_24(int id0);
  public void SetCompositeIndex(int id0)
    { SetCompositeIndex_24(id0); }

  private native int GetCompositeIndex_25();
  public int GetCompositeIndex()
    { return GetCompositeIndex_25(); }

  private native void SetHierarchicalLevel_26(int id0);
  public void SetHierarchicalLevel(int id0)
    { SetHierarchicalLevel_26(id0); }

  private native int GetHierarchicalLevel_27();
  public int GetHierarchicalLevel()
    { return GetHierarchicalLevel_27(); }

  private native void SetHierarchicalIndex_28(int id0);
  public void SetHierarchicalIndex(int id0)
    { SetHierarchicalIndex_28(id0); }

  private native int GetHierarchicalIndex_29();
  public int GetHierarchicalIndex()
    { return GetHierarchicalIndex_29(); }

  private native void SetQueryString_30(String id0);
  public void SetQueryString(String id0)
    { SetQueryString_30(id0); }

  private native String GetQueryString_31();
  public String GetQueryString()
    { return GetQueryString_31(); }

  public vtkSelectionSource() { super(); }

  public vtkSelectionSource(long id) { super(id); }
  public native long   VTKInit();

}
